Microservice-Request
====================

Application for make sync requests (REST API) between microservices .

For testing you should have access to 2 or more projects (at least 1 project - should be Django Project)

Quick start
-----------
1. Install the package
    pip install django-microservice-request (not implemented yet)

2. Add "microservice_request" to your INSTALLED_APPS::

    INSTALLED_APPS = [
        ...
        'microservice_request',
    ]


